==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebToggleViewEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDetailDescription } from "./WebToggleViewEventArgsDetailDescription";
/**
 * @hidden
 */
var WebToggleViewEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleViewEventArgsDetailDescriptionMetadata, _super);
    function WebToggleViewEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebToggleViewEventArgsDetailDescriptionMetadata.a == null) {
            WebToggleViewEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewEventArgsDetailDescriptionMetadata.c(WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebToggleViewEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebToggleViewEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ToggleViewEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Id", "String");
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.d = function (a) {
        WebToggleViewEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebToggleViewEventArgsDetail", function () { return new WebToggleViewEventArgsDetailDescription(); });
        a.z("WebToggleViewEventArgsDetail", WebToggleViewEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.$t = markType(WebToggleViewEventArgsDetailDescriptionMetadata, 'WebToggleViewEventArgsDetailDescriptionMetadata');
    WebToggleViewEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDetailDescriptionMetadata;
}(Base));
export { WebToggleViewEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebToggleViewEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDetailDescription } from "./WebToggleViewEventArgsDetailDescription";
/**
 * @hidden
 */
var WebToggleViewEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleViewEventArgsDetailDescriptionMetadata, _super);
    function WebToggleViewEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebToggleViewEventArgsDetailDescriptionMetadata.a == null) {
            WebToggleViewEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewEventArgsDetailDescriptionMetadata.c(WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebToggleViewEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebToggleViewEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ToggleViewEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Id", "String");
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.d = function (a) {
        WebToggleViewEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebToggleViewEventArgsDetail", function () { return new WebToggleViewEventArgsDetailDescription(); });
        a.ab("WebToggleViewEventArgsDetail", WebToggleViewEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDetailDescriptionMetadata.$t = markType(WebToggleViewEventArgsDetailDescriptionMetadata, 'WebToggleViewEventArgsDetailDescriptionMetadata');
    WebToggleViewEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDetailDescriptionMetadata;
}(Base));
export { WebToggleViewEventArgsDetailDescriptionMetadata };
